@@ -20,6 +20,7 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <tepl/tepl.h>
+#include "tepl/tepl-file-content.h"
 
 #define DEFAULT_CONTENTS "My shiny content!"
 #define MAX_SIZE 10000
@@ -280,6 +281,24 @@ test_loader (const gchar     *contents,
 	test_data_free (data);
 }
 
+static void
+test_empty (void)
+{
+	/* uchardet returns unknown encoding, this relies on the fallback mode
+	 * to determine the encoding.
+	 * See uchardet bug:
+	 * https://bugs.freedesktop.org/show_bug.cgi?id=103280
+	 */
+	test_loader ("",
+		     "",
+		     0, 0,
+		     "UTF-8",
+		     TEPL_NEWLINE_TYPE_DEFAULT,
+		     1,
+		     TRUE,
+		     MAX_SIZE);
+}
+
 static void
 test_loader_newlines (gboolean         implicit_trailing_newline,
 		      const gchar     *contents,
@@ -331,7 +350,7 @@ test_split_cr_lf (void)
 	gchar *content;
 	gint expected_line_count;
 
-	block_size = _tepl_file_loader_get_encoding_converter_buffer_size ();
+	block_size = _tepl_file_content_get_encoding_converter_buffer_size ();
 	/* Remove terminating nul byte */
 	block_size--;
 
@@ -647,12 +666,13 @@ test_readonly (void)
 }
 #endif /* !G_OS_WIN32 */
 
-gint
-main (gint   argc,
-      gchar *argv[])
+int
+main (int    argc,
+      char **argv)
 {
 	gtk_test_init (&argc, &argv);
 
+	g_test_add_func ("/file-loader/empty", test_empty);
 	g_test_add_func ("/file-loader/newlines", test_newlines);
 	g_test_add_func ("/file-loader/split-cr-lf", test_split_cr_lf);
 	g_test_add_func ("/file-loader/max-size", test_max_size);
